rpms/hdf5/devel hdf5-1.8.3-snap12-signal.patch, NONE, 1.1 hdf5-1.8.3-snap12-tstlite.patch, NONE, 1.1 .cvsignore, 1.12, 1.13 hdf5.spec, 1.38, 1.39 sources, 1.12, 1.13 hdf5-1.8.0-longdouble.patch, 1.1, NONE hdf5-1.8.1-filter-as-option.patch, 1.1, NONE hdf5-1.8.3-detect.patch, 1.1, NONE hdf5-1.8.3-signal.patch, 1.1, NONE

Orion Poplawski orion at fedoraproject.org
Thu Oct 1 22:08:47 UTC 2009


Author: orion

Update of /cvs/pkgs/rpms/hdf5/devel
In directory cvs1.fedora.phx.redhat.com:/tmp/cvs-serv8146

Modified Files:
	.cvsignore hdf5.spec sources 
Added Files:
	hdf5-1.8.3-snap12-signal.patch hdf5-1.8.3-snap12-tstlite.patch 
Removed Files:
	hdf5-1.8.0-longdouble.patch hdf5-1.8.1-filter-as-option.patch 
	hdf5-1.8.3-detect.patch hdf5-1.8.3-signal.patch 
Log Message:
* Tue Jun 2 2009 Orion Poplawski <orion at cora.nwra.com> 1.8.3-1
- Update to 1.8.3
- Update signal and detect patches
- Drop open patch fixed upstream


hdf5-1.8.3-snap12-signal.patch:
 H5detect.c |   14 +++++++-------
 1 file changed, 7 insertions(+), 7 deletions(-)

--- NEW FILE hdf5-1.8.3-snap12-signal.patch ---
--- hdf5-1.8.3-snap12/hl/fortran/test/Makefile.in.tstlite	2009-09-21 16:41:49.000000000 -0600
+++ hdf5-1.8.3-snap12/hl/fortran/test/Makefile.in	2009-10-01 14:05:01.628777355 -0600
@@ -355,7 +355,7 @@
 @FORTRAN_SHARED_CONDITIONAL_FALSE at AM_LDFLAGS = -static
 
 # Our main target, the test programs
-TEST_PROG = tstlite tstimage tsttable
+TEST_PROG = tstimage tsttable
 LDADD = $(LIBH5F_HL) $(LIBH5F) $(LIBH5_HL)  $(LIBHDF5)
 
 # Source files for the programs


Index: .cvsignore
===================================================================
RCS file: /cvs/pkgs/rpms/hdf5/devel/.cvsignore,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -p -r1.12 -r1.13
--- .cvsignore	2 Jun 2009 17:26:05 -0000	1.12
+++ .cvsignore	1 Oct 2009 22:08:46 -0000	1.13
@@ -1 +1 @@
-hdf5-1.8.3.tar.gz
+hdf5-1.8.3-snap12.tar.gz


Index: hdf5.spec
===================================================================
RCS file: /cvs/pkgs/rpms/hdf5/devel/hdf5.spec,v
retrieving revision 1.38
retrieving revision 1.39
diff -u -p -r1.38 -r1.39
--- hdf5.spec	25 Jul 2009 02:04:30 -0000	1.38
+++ hdf5.spec	1 Oct 2009 22:08:46 -0000	1.39
@@ -1,18 +1,21 @@
+%define snaprel -snap12
 Name: hdf5
 Version: 1.8.3
-Release: 2%{?dist}
+Release: 3.snap12%{?dist}
 Summary: A general purpose library and file format for storing scientific data
 License: BSD
 Group: System Environment/Libraries
 URL: http://www.hdfgroup.org/HDF5/
-Source0: ftp://ftp.hdfgroup.org/HDF5/current/src/%{name}-%{version}.tar.gz
-#Source0: ftp://ftp.hdfgroup.uiuc.edu/pub/outgoing/hdf5/snapshots/v18/hdf5-1.8.1-rc1.tar.gz
+#Source0: ftp://ftp.hdfgroup.org/HDF5/current/src/%{name}-%{version}.tar.gz
+Source0: ftp://ftp.hdfgroup.uiuc.edu/pub/outgoing/hdf5/snapshots/v18/hdf5-%{version}%{?snaprel}.tar.gz
 Source1: h5comp
-Patch1: hdf5-1.8.3-signal.patch
-Patch2: hdf5-1.8.3-detect.patch
+Patch1: hdf5-1.8.3-snap12-signal.patch
 Patch3: hdf5-1.8.0-multiarch.patch
-Patch5: hdf5-1.8.0-longdouble.patch
-Patch6: hdf5-1.8.1-filter-as-option.patch
+# There is a problem with the h5ltread_dataset_string_f() api in that the 
+# string will be NULL terminated.  The tstlite test ends up crashing with
+# a stack smash.  Reported upstream 9/30/2009, but probably will take a bit
+# of work to fix.  This disables that test
+Patch4: hdf5-1.8.3-snap12-tstlite.patch
 BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
 BuildRequires: krb5-devel, openssl-devel, zlib-devel, gcc-gfortran, time
 
@@ -45,14 +48,11 @@ HDF5 static libraries.
 
 
 %prep
-%setup -q
+%setup -q -n %{name}-%{version}%{?snaprel}
 %patch1 -p1 -b .signal
-%patch2 -p1 -b .detect
 %patch3 -p1 -b .multiarch
-%ifarch ppc64
-%patch5 -p1 -b .longdouble
-%endif
-%patch6 -p1 -b .filter-as-option
+%patch4 -p1 -b .tstlite
+find -name '*.[ch]' -o -name '*.f90' -exec chmod -x {} +
 
 
 %build
@@ -60,10 +60,15 @@ export CC=gcc
 export CXX=g++
 export F9X=gfortran
 export CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing"
-# Must turn of production mode to preserve -g during compile
-%configure --enable-production=no --enable-debug=no \
-           --enable-cxx --enable-fortran \
-           --with-ssl
+%configure \
+  --disable-dependency-tracking \
+  --enable-cxx \
+  --enable-fortran \
+  --enable-hl \
+  --with-ssl
+# --enable-cxx/fortran and --enable-parallel flags are incompatible
+#  --with-mpe=DIR          Use MPE instrumentation [default=no]
+# --enable-cxx/fortran/parallel and --enable-threadsafe flags are incompatible
 #Multiarch header
 %ifarch x86_64 ppc64 ia64 s390x sparc64 alpha
 cp src/H5pubconf.h \
@@ -159,6 +164,14 @@ rm -rf $RPM_BUILD_ROOT
 
 
 %changelog
+* Thu Oct 1 2009 Orion Poplawski <orion at cora.nwra.com> 1.8.3-3.snap12
+- Update to 1.8.3-snap12
+- Update signal patch
+- Drop detect and filter-as-option patch fixed upstream
+- Drop ppc only patch
+- Add patch to skip tstlite test for now, problem reported upstream
+- Fixup some source file permissions
+
 * Fri Jul 24 2009 Fedora Release Engineering <rel-eng at lists.fedoraproject.org> - 1.8.3-2
 - Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild
 
@@ -249,7 +262,7 @@ rm -rf $RPM_BUILD_ROOT
 - Add patch to use POSIX sort key option
 - Remove useless and multilib conflicting Makefiles from html docs
   (bug #228365)
-- Make hdf5-devel own %{_docdir}/%{name}
+- Make hdf5-devel own %%{_docdir}/%%{name}
 
 * Tue Aug 29 2006 Orion Poplawski <orion at cora.nwra.com> 1.6.5-6
 - Rebuild for FC6
@@ -292,9 +305,9 @@ rm -rf $RPM_BUILD_ROOT
 
 * Wed Jul 01 2005 Orion Poplawski <orion at cora.nwra.com> 1.6.4-3
 - Add --enable-threads --with-pthreads to configure
-- Add %check
-- Add some %docs
-- Use %makeinstall
+- Add %%check
+- Add some %%docs
+- Use %%makeinstall
 - Add patch to fix test for h5repack
 - Add patch to fix h5diff_attr.c
 


Index: sources
===================================================================
RCS file: /cvs/pkgs/rpms/hdf5/devel/sources,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -p -r1.12 -r1.13
--- sources	2 Jun 2009 17:26:06 -0000	1.12
+++ sources	1 Oct 2009 22:08:46 -0000	1.13
@@ -1 +1 @@
-5ce228d860bf9e797ca40ab1a823c380  hdf5-1.8.3.tar.gz
+5ef4a3940a8952fe057a176b93e9b176  hdf5-1.8.3-snap12.tar.gz


--- hdf5-1.8.0-longdouble.patch DELETED ---


--- hdf5-1.8.1-filter-as-option.patch DELETED ---


--- hdf5-1.8.3-detect.patch DELETED ---


--- hdf5-1.8.3-signal.patch DELETED ---




More information about the fedora-extras-commits mailing list
--- hdf5-1.8.3-snap12/src/H5detect.c.signal	2009-09-21 16:41:39.000000000 -0600
+++ hdf5-1.8.3-snap12/src/H5detect.c	2009-09-30 10:04:26.657899636 -0600
@@ -111,7 +111,7 @@
 static void insert_libhdf5_settings(FILE *flibinfo);
 static void make_libinfo(void);
 static size_t align_g[] = {1, 2, 4, 8, 16};
-static jmp_buf jbuf_g;
+static sigjmp_buf jbuf_g;
 
 

 /*-------------------------------------------------------------------------
@@ -370,7 +370,7 @@
     void		(*_handler2)(int) = signal(SIGSEGV, sigsegv_handler);	\
 									      \
     _buf = (char*)malloc(sizeof(TYPE) + align_g[NELMTS(align_g) - 1]);	      \
-    if(setjmp(jbuf_g)) _ano++;						      \
+    if(sigsetjmp(jbuf_g, 1)) _ano++;					      \
     if(_ano < NELMTS(align_g)) {					      \
 	*((TYPE*)(_buf+align_g[_ano])) = _val; /*possible SIGBUS or SEGSEGV*/	\
 	_val2 = *((TYPE*)(_buf+align_g[_ano]));	/*possible SIGBUS or SEGSEGV*/	\
@@ -387,7 +387,7 @@
 	    memcpy(_buf+align_g[_ano]+(INFO.offset/8),((char *)&_val)+(INFO.offset/8),(size_t)(INFO.precision/8)); \
 	_val2 = *((TYPE*)(_buf+align_g[_ano]));				      \
 	if(_val!=_val2)							      \
-	    longjmp(jbuf_g, 1);			        		      \
+	    siglongjmp(jbuf_g, 1);			        		      \
 	/* End Cray Check */						      \
 	(INFO.align)=align_g[_ano];					      \
     } else {								      \
@@ -458,7 +458,7 @@
  *		it's not nearly as nice to work with, it does the job for
  *		this simple stuff.
  *
  * Return:	Returns via longjmp to jbuf_g.
  *
  * Programmer:	Robb Matzke
  *		Thursday, March 18, 1999
@@ -471,7 +471,7 @@
 sigsegv_handler(int UNUSED signo)
 {
     signal(SIGSEGV, sigsegv_handler);
-    longjmp(jbuf_g, 1);
+    siglongjmp(jbuf_g, 1);
 }
 
 

@@ -483,7 +483,7 @@
  *		it's not nearly as nice to work with, it does the job for
  *		this simple stuff.
  *
  * Return:	Returns via longjmp to jbuf_g.
  *
  * Programmer:	Robb Matzke
  *		Thursday, March 18, 1999
@@ -496,7 +496,7 @@
 sigbus_handler(int UNUSED signo)
 {
     signal(SIGBUS, sigbus_handler);
-    longjmp(jbuf_g, 1);
+    siglongjmp(jbuf_g, 1);
 #ifdef H5_HAVE_SIGLONGJMP
     siglongjmp(jbuf_g, 1);
 #endif /* H5_HAVE_SIGLONGJMP */

hdf5-1.8.3-snap12-tstlite.patch:
 Makefile.in |    2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

--- NEW FILE hdf5-1.8.3-snap12-tstlite.patch ---
@@ -458,7 +458,7 @@
  *		this simple stuff.
  *
- * Return:	Returns via longjmp to jbuf_g.
+ * Return:	Returns via siglongjmp to jbuf_g.
  *
  * Programmer:	Robb Matzke
@@ -483,7 +483,7 @@
  *		this simple stuff.
  *
- * Return:	Returns via longjmp to jbuf_g.
+ * Return:	Returns via siglongjmp to jbuf_g.
  *
  * Programmer:	Robb Matzke